netapp_ontap.models.lun_qos_policy API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.lun_qos_policy`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class LunQosPolicySchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the LunQosPolicy object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `links GET`

    The links field of the lun_qos_policy.

  `name GET POST PATCH`

    The name of the QoS policy. To remove the QoS policy from a LUN, leaving it with no QoS policy, set this property to an empty string ("") in a PATCH request. Valid in POST and PATCH.

    Example: qos1

  `uuid GET POST PATCH`

    The unique identifier of the QoS policy. Valid in POST and PATCH.

    Example: 1cd8a442-86d1-11e0-ae1c-123478563412